@@ -1,7 +1,5 @@
 #' Get a gist
 #'
-#' @importFrom httr GET POST PATCH PUT DELETE content stop_for_status 
-#' add_headers warn_for_status
 #' @export
 #' @param id (character) A gist id, or a gist URL
 #' @param x Object to coerce. Can be an integer (gist id), string
@@ -94,10 +92,10 @@ get_gistid <- function(x) {
 }
 
 list2gist <- function(x){
-  nmz <- c('url','forks_url','commits_url','id','git_pull_url','git_push_url','html_url',
-           'files','public','created_at','updated_at','description','comments','user',
-           'comments_url','owner','fork_of','forks','history')
-  if (!all(names(x) %in% nmz)) {
+  nmz <- c('comments','comments_url','commits_url','created_at','description',
+           'files','forks_url','git_pull_url','git_push_url','html_url','id',
+           'public','truncated','updated_at','url','user')
+  if (!all(sort(nmz) %in% sort(names(x)))) {
     stop("Not coerceable to a gist", call. = FALSE)
   }
   structure(x, class = "gist")
